bayespy.inference.vmp.nodes.gaussian.GaussianDistribution.compute_cgf_from_parents
==================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianDistribution.compute_cgf_from_parents